@@ -192,7 +192,10 @@ sub _make_field {
         my @names       = split /\./, $field_attr->{name};
         my $simple_name = pop @names;
         my $parent_name = join '.', @names;
-        my $parent      = $self->field($parent_name);
+        # use special 'field' method call that starts from
+        # $self, because names aren't always starting from 
+        # the form
+        my $parent      = $self->field($parent_name, undef, $self);
         if ($parent) {
             die "The parent of field " . $field_attr->{name} . " is not a Compound Field"
                 unless $parent->isa('HTML::FormHandler::Field::Compound');
@@ -301,7 +304,7 @@ HTML::FormHandler::BuildFields - role to build field array
 
 =head1 VERSION
 
-version 0.35004
+version 0.35005
 
 =head1 SYNOPSIS
 
